@@ -35,9 +35,8 @@ class Buienalarm:
         self.precipitation = {}
         self.total = 0
         self.timeframe = int(timeframe / 5)
-        self.renew = None
+        self.renew = -1
         self.data = None
-        self.update()
 
     def get_forecast(self):
         """Get the precipitation forecast"""
